def 进制转换_二进制转十六进制(二进制字符串):
    """
    将二进制字符串转换为十六进制字符串

    :param 二进制字符串: 输入的二进制字符串
    :return: 转换后的十六进制字符串，如果输入不是有效的二进制字符串则返回 None

    示例使用:
    十六进制字符串 = 进制转换_二进制转十六进制('110010101011')
    """

    try:
        十六进制字符串 = hex(int(二进制字符串, 2))
        return 十六进制字符串
    except ValueError:
        return None