def 列表_取成员索引(列表, 目标成员):
    """
    在列表中寻找特定成员（元素），并返回第一次出现的位置的索引。

    参数:
    - 列表 (list): 包含元素的列表
    - 目标成员: 要查找的成员（元素）

    返回:
    - 索引 (int): 第一次出现的位置的索引，如果没有找到则返回 None
    """
    try:
        索引 = 列表.index(目标成员)
    except Exception:
        return None
    return 索引
