def 列表_取元素出现次数(列表, 目标元素):
    """
    统计目标元素在列表中出现的次数。

    参数:
    - 列表 (list): 包含元素的列表
    - 目标元素: 要统计出现次数的目标元素

    返回:
    - 出现次数 (int): 目标元素在列表中出现的次数，如果出现异常则返回 None
    """
    出现次数 = 0

    try:
        for 元素 in 列表:
            if 元素 == 目标元素:
                出现次数 += 1
    except Exception:
        # 如果出现异常，返回 None
        return None
    return 出现次数


