def 进制转换_二进制转三十二进制(二进制字符串):
    """
    将二进制字符串转换为三十二进制字符串

    :param 二进制字符串: 输入的二进制字符串
    :return: 转换后的三十二进制字符串，如果输入不是有效的二进制字符串则返回 None

    示例使用:
    三十二进制字符串 = 进制转换_二进制转三十二进制('110010101011')
    """

    try:
        三十二进制字符串 = ''.join([str(int(二进制字符串[i:i + 5], 2)) for i in range(0, len(二进制字符串), 5)])
        return 三十二进制字符串
    except ValueError:
        return None